
.. include:: ../../README.rst

============
Installation
============

.. code-block:: shell

    $ pip install pygeoprocessing

=============
API Reference
=============

.. toctree::
    :maxdepth: 1

    packages/geoprocessing.rst
    packages/routing.rst
    packages/fileio.rst

=======
Testing
=======

.. toctree::
    :maxdepth: 1

    testing.rst
    sampledata.rst


========================
Other Useful Information
========================

.. toctree::
   :maxdepth: 1

   examples
   package-testing
   history

==================
Indices and Tables
==================

 * :ref:`genindex`
 * :ref:`modindex`
 * :ref:`search`
